==> brmo-stufbg204-1.5.2-sources.jar: nl/egem/stuf/sector/bg/_0204/ADRVraag.java <==

package nl.egem.stuf.sector.bg._0204;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElementRef;
import javax.xml.bind.annotation.XmlType;


/**
 * adres binnen vraagberichten
 * 
 * <p>Java class for ADR-vraag complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="ADR-vraag">
 *   &lt;complexContent>
 *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}ADR-fund">
 *       &lt;sequence>
 *         &lt;element name="ADRADROSU" minOccurs="0">
 *           &lt;complexType>
 *             &lt;complexContent>
 *               &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}ADRADROSU-rel">
 *                 &lt;sequence>
 *                   &lt;element name="ADR" type="{http://www.egem.nl/StUF/sector/bg/0204}ADR-kennisgeving"/>
 *                 &lt;/sequence>
 *               &lt;/extension>
 *             &lt;/complexContent>
 *           &lt;/complexType>
 *         &lt;/element>
 *       &lt;/sequence>
 *     &lt;/extension>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ADR-vraag", propOrder = {
    "adradrosu"
})
public class ADRVraag
    extends ADRFund
{

    @XmlElementRef(name = "ADRADROSU", namespace = "http://www.egem.nl/StUF/sector/bg/0204", type = JAXBElement.class, required = false)
    protected JAXBElement<ADRVraag.ADRADROSU> adradrosu;

    /**
     * Gets the value of the adradrosu property.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link ADRVraag.ADRADROSU }{@code >}
     *     
     */
    public JAXBElement<ADRVraag.ADRADROSU> getADRADROSU() {
        return adradrosu;
    }

    /**
     * Sets the value of the adradrosu property.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link ADRVraag.ADRADROSU }{@code >}
     *     
     */
    public void setADRADROSU(JAXBElement<ADRVraag.ADRADROSU> value) {
        this.adradrosu = value;
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType>
     *   &lt;complexContent>
     *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}ADRADROSU-rel">
     *       &lt;sequence>
     *         &lt;element name="ADR" type="{http://www.egem.nl/StUF/sector/bg/0204}ADR-kennisgeving"/>
     *       &lt;/sequence>
     *     &lt;/extension>
     *   &lt;/complexContent>
     * &lt;/complexType>
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "adr"
    })
    public static class ADRADROSU
        extends ADRADROSURel
    {

        @XmlElement(name = "ADR", required = true, nillable = true)
        protected ADRKennisgeving adr;

        /**
         * Gets the value of the adr property.
         * 
         * @return
         *     possible object is
         *     {@link ADRKennisgeving }
         *     
         */
        public ADRKennisgeving getADR() {
            return adr;
        }

        /**
         * Sets the value of the adr property.
         * 
         * @param value
         *     allowed object is
         *     {@link ADRKennisgeving }
         *     
         */
        public void setADR(ADRKennisgeving value) {
            this.adr = value;
        }

    }

}

==> brmo-stufbg204-2.0.0-sources.jar: nl/egem/stuf/sector/bg/_0204/ADRVraag.java <==

package nl.egem.stuf.sector.bg._0204;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElementRef;
import javax.xml.bind.annotation.XmlType;


/**
 * adres binnen vraagberichten
 * 
 * <p>Java class for ADR-vraag complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="ADR-vraag"&gt;
 *   &lt;complexContent&gt;
 *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}ADR-fund"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="ADRADROSU" minOccurs="0"&gt;
 *           &lt;complexType&gt;
 *             &lt;complexContent&gt;
 *               &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}ADRADROSU-rel"&gt;
 *                 &lt;sequence&gt;
 *                   &lt;element name="ADR" type="{http://www.egem.nl/StUF/sector/bg/0204}ADR-kennisgeving"/&gt;
 *                 &lt;/sequence&gt;
 *               &lt;/extension&gt;
 *             &lt;/complexContent&gt;
 *           &lt;/complexType&gt;
 *         &lt;/element&gt;
 *       &lt;/sequence&gt;
 *     &lt;/extension&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ADR-vraag", propOrder = {
    "adradrosu"
})
public class ADRVraag
    extends ADRFund
{

    @XmlElementRef(name = "ADRADROSU", namespace = "http://www.egem.nl/StUF/sector/bg/0204", type = JAXBElement.class, required = false)
    protected JAXBElement<ADRVraag.ADRADROSU> adradrosu;

    /**
     * Gets the value of the adradrosu property.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link ADRVraag.ADRADROSU }{@code >}
     *     
     */
    public JAXBElement<ADRVraag.ADRADROSU> getADRADROSU() {
        return adradrosu;
    }

    /**
     * Sets the value of the adradrosu property.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link ADRVraag.ADRADROSU }{@code >}
     *     
     */
    public void setADRADROSU(JAXBElement<ADRVraag.ADRADROSU> value) {
        this.adradrosu = value;
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType&gt;
     *   &lt;complexContent&gt;
     *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}ADRADROSU-rel"&gt;
     *       &lt;sequence&gt;
     *         &lt;element name="ADR" type="{http://www.egem.nl/StUF/sector/bg/0204}ADR-kennisgeving"/&gt;
     *       &lt;/sequence&gt;
     *     &lt;/extension&gt;
     *   &lt;/complexContent&gt;
     * &lt;/complexType&gt;
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "adr"
    })
    public static class ADRADROSU
        extends ADRADROSURel
    {

        @XmlElement(name = "ADR", required = true, nillable = true)
        protected ADRKennisgeving adr;

        /**
         * Gets the value of the adr property.
         * 
         * @return
         *     possible object is
         *     {@link ADRKennisgeving }
         *     
         */
        public ADRKennisgeving getADR() {
            return adr;
        }

        /**
         * Sets the value of the adr property.
         * 
         * @param value
         *     allowed object is
         *     {@link ADRKennisgeving }
         *     
         */
        public void setADR(ADRKennisgeving value) {
            this.adr = value;
        }

    }

}
